/****************************************************************************
 **             - iocan128.h -
 **
 **     This file declares the internal register addresses for AT90CAN128.
 **
 **     Used with iccAVR and aAVR.
 **
 **     Copyright IAR Systems 2004. All rights reserved.
 **
 **     File version: $Revision: 1.7 $
 **
 ***************************************************************************/

#include "iomacro.h"

#if TID_GUARD(3)
#error This file should only be compiled with iccavr or aavr whith processor option -v3
#endif /* TID_GUARD(3) */

/* Include the SFR part if this file has not been included before,
 * OR this file is included by the assembler (SFRs must be defined in
 * each assembler module). */
#if !defined(__IOCAN128_H) || defined(__IAR_SYSTEMS_ASM__)

#pragma language=extended

/*==========================*/
/* Predefined SFR Addresses */
/*==========================*/

/****************************************************************************
 * An example showing the SFR_B() macro call, 
 * the expanded result and usage of this result:
 *
 * SFR_B_R(0x1F,   AVR) Expands to:
 * __io union {
 *             unsigned char AVR;                 // The sfrb as 1 byte
 *             struct {                           // The sfrb as 8 bits
 *                     unsigned char AVR_Bit0:1,
 *                                   AVR_Bit1:1,
 *                                   AVR_Bit2:1,
 *                                   AVR_Bit3:1,
 *                                   AVR_Bit4:1,
 *                                   AVR_Bit5:1,
 *                                   AVR_Bit6:1,
 *                                   AVR_Bit7:1;
 *                    };
 *            } @ 0x1F;
 * Examples of how to use the expanded result:
 * AVR |= (1<<5);
 * or like this:
 * AVR_Bit5 = 1;
 *
 *
 *
 * An example showing the SFR_B_N() macro call, 
 * the expanded result and usage of this result:
 * SFR_B_N(0x25,  TCCR2, FOC2, WGM20, COM21, COM20, WGM21, CS22, CS21, CS20)
 *  Expands to:
 *  __io union { 
 *              unsigned char TCCR2; 
 *              struct { 
 *                      unsigned char TCCR2_Bit0:1, 
 *                                    TCCR2_Bit1:1, 
 *                                    TCCR2_Bit2:1, 
 *                                    TCCR2_Bit3:1, 
 *                                    TCCR2_Bit4:1, 
 *                                    TCCR2_Bit5:1, 
 *                                    TCCR2_Bit6:1, 
 *                                    TCCR2_Bit7:1; 
 *                     }; 
 *              struct { 
 *                      unsigned char TCCR2_CS20:1, 
 *                                    TCCR2_CS21:1, 
 *                                    TCCR2_CS22:1, 
 *                                    TCCR2_WGM21:1, 
 *                                    TCCR2_COM20:1, 
 *                                    TCCR2_COM21:1, 
 *                                    TCCR2_WGM20:1, 
 *                                    TCCR2_FOC2:1; 
 *                     }; 
 *             } @ 0x25;
 * Examples of how to use the expanded result:
 * TCCR2 |= (1<<5); 
 * or if ENABLE_BIT_DEFINITIONS is defined   
 * TCCR2 |= (1<<COM21);
 * or like this:
 * TCCR2_Bit5 = 1;
 * or like this:
 * TCCR2_COM21 = 1;
 ***************************************************************************/

/* Extended I/O space */

SFR_B_N(0xFA,   CANMSG, MSG7, MSG6, MSG5, MSG4, MSG3, MSG2, MSG1, MSG0)
SFR_W_N(0xF8,   CANSTM, TIMSTM15, TIMSTM14, TIMSTM13, TIMSTM12, TIMSTM11, TIMSTM10, TIMSTM9, TIMSTM8, TIMSTM7, TIMSTM6, TIMSTM5, TIMSTM4, TIMSTM3, TIMSTM2, TIMSTM1, TIMSTM0)
SFR_B_N(0xF7,   CANIDM1, IDMSK28, IDMSK27, IDMSK26, IDMSK25, IDMSK24, IDMSK23, IDMSK22, IDMSK21)
SFR_B_N(0xF6,   CANIDM2, IDMSK20, IDMSK19, IDMSK18, IDMSK17, IDMSK16, IDMSK15, IDMSK14, IDMSK13)
SFR_B_N(0xF5,   CANIDM3, IDMSK12, IDMSK11, IDMSK10, IDMSK9, IDMSK8, IDMSK7, IDMSK6, IDMSK5)
SFR_B_N(0xF4,   CANIDM4, IDMSK4, IDMSK3, IDMSK2, IDMSK1, IDMSK0, RTRMSK, Dummy1, IDEMSK)
SFR_B_N(0xF3,   CANIDT1, IDT28, IDT27, IDT26, IDT25, IDT24, IDT23, IDT22, IDT21)
SFR_B_N(0xF2,   CANIDT2, IDT20, IDT19, IDT18, IDT17, IDT16, IDT15, IDT14, IDT13)
SFR_B_N(0xF1,   CANIDT3, IDT12, IDT11, IDT10, IDT9, IDT8, IDT7, IDT6, IDT5)
SFR_B_N(0xF0,   CANIDT4, IDT4, IDT3, IDT2, IDT1, IDT0, RTRTAG, RB1TAG, RB0TAG)
SFR_B_N(0xEF,   CANCDMOB, CONMOB1, CONMOB0, RPLV, IDE, DLC3, DLC2, DLC1, DLC0)
SFR_B_N(0xEE,   CANSTMOB, DLCW, TXOK, RXOK, BERR, SERR, CERR, FERR, AERR)
SFR_B_N(0xED,   CANPAGE, MOBNB3, MOBNB2, MOBNB1, MOBNB0, AINC, INDX2, INDX1, INDX0)
SFR_B_N(0xEC,   CANHPMOB, HPMOB3, HPMOB2, HPMOB1, HPMOB0, CGP3, CGP2, CGP1, CGP0)
SFR_B_N(0xEB,   CANREC, REC7, REC6, REC5, REC4, REC3, REC2, REC1, REC0)
SFR_B_N(0xEA,   CANTEC, TEC7, TEC6, TEC5, TEC4, TEC3, TEC2, TEC1, TEC0)
SFR_W_N(0xE8,   CANTTC, TIMTTC15, TIMTTC14, TIMTTC13, TIMTTC12, TIMTTC11, TIMTTC10, TIMTTC9, TIMTTC8, TIMTTC7, TIMTTC6, TIMTTC5, TIMTTC4, TIMTTC3, TIMTTC2, TIMTTC1, TIMTTC0)
SFR_W_N(0xE6,   CANTIM, CANTIM15, CANTIM14, CANTIM13, CANTIM12, CANTIM11, CANTIM10, CANTIM9, CANTIM8, CANTIM7, CANTIM6, CANTIM5, CANTIM4, CANTIM3, CANTIM2, CANTIM1, CANTIM0)
SFR_B_N(0xE5,   CANTCON, TPRSC7, TPRSC6, TPRSC5, TPRSC4, TPRSC3, TPRSC2, TRPSC1, TPRSC0)
SFR_B_N(0xE4,   CANBT3, Dummy7, PHS22, PHS21, PHS20, PHS12, PHS11, PHS10, SMP)
SFR_B_N(0xE3,   CANBT2, Dummy7, SJW1, SJW0, Dummy4, PRS2, PRS1, PRS0, Dummy0)
SFR_B_N(0xE2,   CANBT1, Dummy7, BRP5, BRP4, BRP3, BRP2, BRP1, BRP0, Dummy0)
SFR_B_N(0xE1,   CANSIT1, Dummy7, SIT14, SIT13, SIT12, SIT11, SIT10, SIT9, SIT8)
SFR_B_N(0xE0,   CANSIT2, SIT7, SIT6, SIT5, SIT4, SIT3, SIT2, SIT1, SIT0)
SFR_B_N(0xDF,   CANIE1, Dummy7, IEMOB14, IEMOB13, IEMOB12, IEMOB11, IEMOB10, IEMOB9, IEMOB8)
SFR_B_N(0xDE,   CANIE2, IEMOB7, IEMOB6, IEMOB5, IEMOB4, IEMOB3, IEMOB2, IEMOB1, IEMOB0)
SFR_B_N(0xDD,   CANEN1, Dummy7, ENMOB14, ENMOB13, ENMOB12, ENMOB11, ENMOB10, ENMOB9, ENMOB8)
SFR_B_N(0xDC,   CANEN2, ENMOB7, ENMOB6, ENMOB5, ENMOB4, ENMOB3, ENMOB2, ENMOB1, ENMOB0)
SFR_B_N(0xDB,   CANGIE, ENIT, ENBOFF, ENRX, ENTX, ENERR, ENBX, ENERG, ENOVRT)
SFR_B_N(0xDA,   CANGIT, CANIT, BOFFIT, OVRTIM, BXOK, SERG, CERG, FERG, AERG)
SFR_B_N(0xD9,   CANGSTA, Dummy7, OVRG, Dummy5, TXBSY, RXBSY, ENFG, BOFF, ERRP)
SFR_B_N(0xD8,   CANGCON, ABRQ, OVRQ, TTC, SYNTTC, LISTEN, TEST, ENASTB, SWRES)
SFR_B_N(0xCE,   UDR1, UDR17, UDR16, UDR15, UDR14, UDR13, UDR12, UDR11, UDR10)
SFR_W_N(0xCC,   UBRR1, Dummy15, Dummy14, Dummy13, Dummy12, UBRR111, UBRR110, UBRR19, UBRR18, UBRR17, UBRR16, UBRR15, UBRR14, UBRR13, UBRR12, UBRR11, UBRR10)
SFR_B_N(0xCA,   UCSR1C, Dummy7, UMSEL1, UPM11, UPM10, USBS1, UCSZ11, UCSZ10, UCPOL1)
SFR_B_N(0xC9,   UCSR1B, RXCIE1, TXCIE1, UDRIE1, RXEN1, TXEN1, UCSZ12, RXB81, TXB81)
SFR_B_N(0xC8,   UCSR1A, RXC1, TXC1, UDRE1, FE1, DOR1, UPE1, U2X1, MPCM1)
SFR_B_N(0xC6,   UDR0, UDR07, UDR06, UDR05, UDR04, UDR03, UDR02, UDR01, UDR00)
SFR_W_N(0xC4,   UBRR0, Dummy15, Dummy14, Dummy13, Dummy12, UBRR011, UBRR010, UBRR09, UBRR08, UBRR07, UBRR06, UBRR05, UBRR04, UBRR03, UBRR02, UBRR01, UBRR00)
SFR_B_N(0xC2,   UCSR0C, Dummy7, UMSEL0, UPM01, UPM00, USBS0, UCSZ01, UCSZ00, UCPOL0)
SFR_B_N(0xC1,   UCSR0B, RXCIE0, TXCIE0, UDRIE0, RXEN0, TXEN0, UCSZ02, RXB80, TXB80)
SFR_B_N(0xC0,   UCSR0A, RXC0, TXC0, UDRE0, FE0, DOR0, UPE0, U2X0, MPCM0)
SFR_B_N(0xBC,   TWCR, TWINT, TWEA, TWSTA, TWSTO, TWWC, TWEN, Dummy1, TWIE)
SFR_B_N(0xBB,   TWDR, TWDR7, TWDR6, TWDR5, TWDR4, TWDR3, TWDR2, TWDR1, TWDR0)
SFR_B_N(0xBA,   TWAR, TWAR6, TWAR5, TWAR4, TWAR3, TWAR2, TWAR1, TWAR0, TWGCE)
SFR_B_N(0xB9,   TWSR, TWS7, TWS6, TWS5, TWS4, TWS3, Dummy2, TWPS1, TWPS0)
SFR_B_N(0xB8,   TWBR, TWBR7, TWBR6, TWBR5, TWBR4, TWBR3, TWBR2, TWBR1, TWBR0)
SFR_B_N(0xB6,   ASSR, Dummy7, Dummy6, Dummy5, EXCLK, AS2, TCN2UB, OCR2UB, TCR2UB)
SFR_B_N(0xB3,   OCR2A, OCR2A7, OCR2A6, OCR2A5, OCR2A4, OCR2A3, OCR2A2, OCR2A1, OCR2A0)
SFR_B_N(0xB2,   TCNT2, TCNT27, TCNT26, TCNT25, TCNT24, TCNT23, TCNT22, TCNT21, TCNT20)
SFR_B_N(0xB0,   TCCR2A, FOC2A, WGM20, COM2A1, COM2A0, WGM21, CS22, CS21, CS20)
SFR_W_N(0x9C,   OCR3C, OCR3C15, OCR3C14, OCR3C13, OCR3C12, OCR3C11, OCR3C10, OCR3C9, OCR3C8, OCR3C7, OCR3C6, OCR3C5, OCR3C4, OCR3C3, OCR3C2, OCR3C1, OCR3C0)
SFR_W_N(0x9A,   OCR3B, OCR3B15, OCR3B14, OCR3B13, OCR3B12, OCR3B11, OCR3B10, OCR3B9, OCR3B8, OCR3B7, OCR3B6, OCR3B5, OCR3B4, OCR3B3, OCR3B2, OCR3B1, OCR3B0)
SFR_W_N(0x98,   OCR3A, OCR3A15, OCR3A14, OCR3A13, OCR3A12, OCR3A11, OCR3A10, OCR3A9, OCR3A8, OCR3A7, OCR3A6, OCR3A5, OCR3A4, OCR3A3, OCR3A2, OCR3A1, OCR3A0)
SFR_W_N(0x96,   ICR3, ICR315, ICR314, ICR313, ICR312, ICR311, ICR310, ICR39, ICR38, ICR37, ICR36, ICR35, ICR34, ICR33, ICR32, ICR31, ICR30)
SFR_W_N(0x94,   TCNT3, TCNT315, TCNT314, TCNT313, TCNT312, TCNT311, TCNT310, TCNT39, TCNT38, TCNT37, TCNT36, TCNT35, TCNT34, TCNT33, TCNT32, TCNT31, TCNT30)
SFR_B_N(0x92,   TCCR3C, FOC3A, FOC3B, FOC3C, Dummy4, Dummy3, Dummy2, Dummy1, Dummy0)
SFR_B_N(0x91,   TCCR3B, ICNC3, ICES3, Dummy5, WGM33, WGM32, CS32, CS31, CS30)
SFR_B_N(0x90,   TCCR3A, COM3A1, COM3A0, COM3B1, COM3B0, COM3C1, COM3C0, WGM31, WGM30)
SFR_W_N(0x8C,   OCR1C, OCR1C15, OCR1C14, OCR1C13, OCR1C12, OCR1C11, OCR1C10, OCR1C9, OCR1C8, OCR1C7, OCR1C6, OCR1C5, OCR1C4, OCR1C3, OCR1C2, OCR1C1, OCR1C0)
SFR_W_N(0x8A,   OCR1B, OCR1B15, OCR1B14, OCR1B13, OCR1B12, OCR1B11, OCR1B10, OCR1B9, OCR1B8, OCR1B7, OCR1B6, OCR1B5, OCR1B4, OCR1B3, OCR1B2, OCR1B1, OCR1B0)
SFR_W_N(0x88,   OCR1A, OCR1A15, OCR1A14, OCR1A13, OCR1A12, OCR1A11, OCR1A10, OCR1A9, OCR1A8, OCR1A7, OCR1A6, OCR1A5, OCR1A4, OCR1A3, OCR1A2, OCR1A1, OCR1A0)
SFR_W_N(0x86,   ICR1, ICR115, ICR114, ICR113, ICR112, ICR111, ICR110, ICR19, ICR18, ICR17, ICR16, ICR15, ICR14, ICR13, ICR12, ICR11, ICR10)
SFR_W_N(0x84,   TCNT1, TCNT115, TCNT114, TCNT113, TCNT112, TCNT111, TCNT110, TCNT19, TCNT18, TCNT17, TCNT16, TCNT15, TCNT14, TCNT13, TCNT12, TCNT11, TCNT10)
SFR_B_N(0x82,   TCCR1C, FOC1A, FOC1B, FOC1C, Dummy4, Dummy3, Dummy2, Dummy1, Dummy0)
SFR_B_N(0x81,   TCCR1B, ICNC1, ICES1, Dummy5, WGM13, WGM12, CS12, CS11, CS10)
SFR_B_N(0x80,   TCCR1A, COM1A1, COM1A0, COM1B1, COM1B0, COM1C1, COM1C0, WGM11, WGM10)
SFR_B_N(0x7F,   DIDR1, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, AIN1D, AIN0D)
SFR_B_N(0x7E,   DIDR0, ADC7D, ADC6D, ADC5D, ADC4D, ADC3D, ADC2D, ADC1D, ADC0D)
SFR_B_N(0x7C,   ADMUX, REFS1, REFS0, ADLAR, MUX4, MUX3, MUX2, MUX1, MUX0)
SFR_B_N(0x7B,   ADCSRB, ADHSM, ACME, Dummy5, Dummy4, Dummy3, ADTS2, ADTS1, ADTS0)
SFR_B_N(0x7A,   ADCSRA, ADEN, ADSC, ADATE, ADIF, ADIE, ADPS2, ADPS1, ADPS0)
SFR_W_R(0x78,   ADC)
SFR_B_N(0x75,   XMCRB, XMBK, Dummy6, Dummy5, Dummy4, Dummy3, XMM2, XMM1, XMM0)
SFR_B_N(0x74,   XMCRA, SRE, SRL2, SRL1, SRL0, SRW11, SRW10, SRW01, SRW00)
SFR_B_N(0x71,   TIMSK3, Dummy7, Dummy6, ICIE3, Dummy4, OCIE3C, OCIE3B, OCIE3A, TOIE3)
SFR_B_N(0x70,   TIMSK2, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, OCIE2A, TOIE2)
SFR_B_N(0x6F,   TIMSK1, Dummy7, Dummy6, ICIE1, Dummy4, OCIE1C, OCIE1B, OCIE1A, TOIE1)
SFR_B_N(0x6E,   TIMSK0, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, OCIE0A, TOIE0)
SFR_B_N(0x6A,   EICRB, ISC71, ISC70, ISC61, ISC60, ISC51, ISC50, ISC41, ISC40)
SFR_B_N(0x69,   EICRA, ISC31, ISC30, ISC21, ISC20, ISC11, ISC10, ISC01, ISC00)
SFR_B_N(0x66,   OSCCAL, Dummy7, CAL6, CAL5, CAL4, CAL3, CAL2, CAL1, CAL0)
SFR_B_N(0x61,   CLKPR, CLKPCE, Dummy6, Dummy5, Dummy4, CLKPS3, CLKPS2, CLKPS1, CLKPS0)
SFR_B_N(0x60,   WDTCR, Dummy7, Dummy6, Dummy5, WDCE, WDE, WDP2, WDP1, WDP0)

/* Ordinary I/O space */

SFR_B_N(0x3F,   SREG, I, T, H, S, V, N, Z, C)
SFR_W_N(0x3D,   SP, SP15, SP14, SP13, SP12, SP11, SP10, SP9, SP8, SP7, SP6, SP5, SP4, SP3, SP2, SP1, SP0)
SFR_B_N(0x3B,   RAMPZ, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, Dummy1, RAMPZ0)
SFR_B_N(0x37,   SPMCSR, SPMIE, RWWSB, Dummy5, RWWSRE, BLBSET, PGWRT, PGERS, SPMEN)
SFR_B_N(0x35,   MCUCR, JTD, Dummy6, Dummy5, PUD, Dummy3, Dummy2, IVSEL, IVCE)
SFR_B_N(0x34,   MCUSR, Dummy7, Dummy6, Dummy5, JTRF, WDRF, BORF, EXTRF, PORF)
SFR_B_N(0x33,   SMCR, Dummy7, Dummy6, Dummy5, Dummy4, SM2, SM1, SM0, SE)
SFR_B_N(0x31,   OCDR, IDRD, OCDR6, OCDR5, OCDR4, OCDR3, OCDR2, OCDR1, OCDR0)
SFR_B_N(0x30,   ACSR, ACD, ACBG, ACO, ACI, ACIE, ACIC, ACIS1, ACIS0)
SFR_B_N(0x2E,   SPDR, SPD7, SPD6, SPD5, SPD4, SPD3, SPD2, SPD1, SPD0)
SFR_B_N(0x2D,   SPSR, SPIF, WCOL, Dummy5, Dummy4, Dummy3, Dummy2, Dummy1, SPI2X)
SFR_B_N(0x2C,   SPCR, SPIE, SPE, DORD, MSTR, CPOL, CPHA, SPR1, SPR0)
SFR_B_N(0x2B,   GPIOR2, GPIOR27, GPIOR26, GPIOR25, GPIOR24, GPIOR23, GPIOR22, GPIOR21, GPIOR20)
SFR_B_N(0x2A,   GPIOR1, GPIOR17, GPIOR16, GPIOR15, GPIOR14, GPIOR13, GPIOR12, GPIOR11, GPIOR10)
SFR_B_N(0x27,   OCR0A, OCR0A7, OCR0A6, OCR0A5, OCR0A4, OCR0A3, OCR0A2, OCR0A1, OCR0A0)
SFR_B_N(0x26,   TCNT0, TCNT07, TCNT06, TCNT05, TCNT04, TCNT03, TCNT02, TCNT01, TCNT00)
SFR_B_N(0x24,   TCCR0A, FOC0A, WGM00, COM0A1, COM0A0, WGM01, CS02, CS01, CS00)
SFR_B_N(0x23,   GTCCR, TSM, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, PSR2, PSR310)
SFR_W_N(0x21,   EEAR, Dummy7, Dummy6, Dummy5, Dummy4, EEAR11, EEAR10, EEAR9, EEAR8, EEAR7, EEAR6, EEAR5, EEAR4, EEAR3, EEAR2, EEAR1, EEAR0)
SFR_B_N(0x20,   EEDR, EEDR7, EEDR6, EEDR5, EEDR4, EEDR3, EEDR2, EEDR1, EEDR0)
SFR_B_N(0x1F,   EECR, Dummy7, Dummy6, Dummy5, Dummy4, EERIE, EEMWE, EEWE, EERE)
SFR_B_N(0x1E,   GPIOR0, GPIOR07, GPIOR06, GPIOR05, GPIOR04, GPIOR03, GPIOR02, GPIOR01, GPIOR00)
SFR_B_N(0x1D,   EIMSK, INT7, INT6, INT5, INT4, INT3, INT2, INT1, INT0)
SFR_B_N(0x1C,   EIFR, INTF7, INTF6, INTF5, INTF4, INTF3, INTF2, INTF1, INTF0)
SFR_B_N(0x18,   TIFR3, Dummy7, Dummy6, ICF3, Dummy4, OCF3C, OCF3B, OCF3A, TOV3)
SFR_B_N(0x17,   TIFR2, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, OCF2A, TOV2)
SFR_B_N(0x16,   TIFR1, Dummy7, Dummy6, ICF1, Dummy4, OCF1C, OCF1B, OCF1A, TOV1)
SFR_B_N(0x15,   TIFR0, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, OCF0A, TOV0)
SFR_B_N(0x14,   PORTG, Dummy7, Dummy6, Dummy5, PORTG4, PORTG3, PORTG2, PORTG1, PORTG0)
SFR_B_N(0x13,   DDRG, Dummy7, Dummy6, Dummy5, DDG4, DDG3, DDG2, DDG1, DDG0)
SFR_B_N(0x12,   PING, Dummy7, Dummy6, Dummy5, PING4, PING3, PING2, PING1, PING0)
SFR_B_N(0x11,   PORTF, PORTF7, PORTF6, PORTF5, PORTF4, PORTF3, PORTF2, PORTF1, PORTF0)
SFR_B_N(0x10,   DDRF, DDF7, DDF6, DDF5, DDF4, DDF3, DDF2, DDF1, DDF0)
SFR_B_N(0x0F,   PINF, PINF7, PINF6, PINF5, PINF4, PINF3, PINF2, PINF1, PINF0)
SFR_B_N(0x0E,   PORTE, PORTE7, PORTE6, PORTE5, PORTE4, PORTE3, PORTE2, PORTE1, PORTE0)
SFR_B_N(0x0D,   DDRE, DDE7, DDE6, DDE5, DDE4, DDE3, DDE2, DDE1, DDE0)
SFR_B_N(0x0C,   PINE, PINE7, PINE6, PINE5, PINE4, PINE3, PINE2, PINE1, PINE0)
SFR_B_N(0x0B,   PORTD, PORTD7, PORTD6, PORTD5, PORTD4, PORTD3, PORTD2, PORTD1, PORTD0)
SFR_B_N(0x0A,   DDRD, DDD7, DDD6, DDD5, DDD4, DDD3, DDD2, DDD1, DDD0)
SFR_B_N(0x09,   PIND, PIND7, PIND6, PIND5, PIND4, PIND3, PIND2, PIND1, PIND0)
SFR_B_N(0x08,   PORTC, PORTC7, PORTC6, PORTC5, PORTC4, PORTC3, PORTC2, PORTC1, PORTC0)
SFR_B_N(0x07,   DDRC, DDC7, DDC6, DDC5, DDC4, DDC3, DDC2, DDC1, DDC0)
SFR_B_N(0x06,   PINC, PINC7, PINC6, PINC5, PINC4, PINC3, PINC2, PINC1, PINC0)
SFR_B_N(0x05,   PORTB, PORTB7, PORTB6, PORTB5, PORTB4, PORTB3, PORTB2, PORTB1, PORTB0)
SFR_B_N(0x04,   DDRB, DDB7, DDB6, DDB5, DDB4, DDB3, DDB2, DDB1, DDB0)
SFR_B_N(0x03,   PINB, PINB7, PINB6, PINB5, PINB4, PINB3, PINB2, PINB1, PINB0)
SFR_B_N(0x02,   PORTA, PORTA7, PORTA6, PORTA5, PORTA4, PORTA3, PORTA2, PORTA1, PORTA0)
SFR_B_N(0x01,   DDRA, DDA7, DDA6, DDA5, DDA4, DDA3, DDA2, DDA1, DDA0)
SFR_B_N(0x00,   PINA, PINA7, PINA6, PINA5, PINA4, PINA3, PINA2, PINA1, PINA0)



#ifndef __IOCAN128_H
#define __IOCAN128_H


/* SFRs are local in assembler modules (so this file may need to be */
/* included in more than one module in the same source file), */
/* but #defines must only be made once per source file. */

/*==============================*/
/* Interrupt Vector Definitions */
/*==============================*/

/* NB! vectors are specified as byte addresses */

#define    RESET_vect           (0x00)
#define    INT0_vect            (0x04)
#define    INT1_vect            (0x08)
#define    INT2_vect            (0x0C)
#define    INT3_vect            (0x10)
#define    INT4_vect            (0x14)
#define    INT5_vect            (0x18)
#define    INT6_vect            (0x1C)
#define    INT7_vect            (0x20)
#define    TIMER2_COMP_vect     (0x24)
#define    TIMER2_OVF_vect      (0x28)
#define    TIMER1_CAPT_vect     (0x2C)
#define    TIMER1_COMPA_vect    (0x30)
#define    TIMER1_COMPB_vect    (0x34)
#define    TIMER1_COMPC_vect    (0x38)
#define    TIMER1_OVF_vect      (0x3C)
#define    TIMER0_COMP_vect     (0x40)
#define    TIMER0_OVF_vect      (0x44)
#define    CANIT_vect           (0x48)
#define    OVRIT_vect           (0x4C)
#define    SPI_STC_vect         (0x50)
#define    USART0_RX_vect       (0x54)
#define    USART0_UDRE_vect     (0x58)
#define    USART0_TX_vect       (0x5C)
#define    ANA_COMP_vect        (0x60)
#define    ADC_vect             (0x64)
#define    EE_RDY_vect          (0x68)
#define    TIMER3_CAPT_vect     (0x6C)
#define    TIMER3_COMPA_vect    (0x70)
#define    TIMER3_COMPB_vect    (0x74)
#define    TIMER3_COMPC_vect    (0x78)
#define    TIMER3_OVF_vect      (0x7C)
#define    USART1_RX_vect       (0x80)
#define    USART1_UDRE_vect     (0x84)
#define    USART1_TX_vect       (0x88)
#define    TWI_vect             (0x8C)
#define    SPM_READY_vect       (0x90)

#ifdef __IAR_SYSTEMS_ASM__   
#ifndef ENABLE_BIT_DEFINITIONS
#define  ENABLE_BIT_DEFINITIONS
#endif /* ENABLE_BIT_DEFINITIONS */
#endif /* __IAR_SYSTEMS_ASM__ */

#ifdef ENABLE_BIT_DEFINITIONS


/* Bit definitions for use with the IAR Assembler   
   The Register Bit names are represented by their bit number (0-7).
*/

        /* CANMSG */
#define MSG7      7
#define MSG6      6
#define MSG5      5
#define MSG4      4
#define MSG3      3
#define MSG2      2
#define MSG1      1
#define MSG0      0

        /* CANSTMH */
#define TIMSTM15   7
#define TIMSTM14   6
#define TIMSTM13   5
#define TIMSTM12   4
#define TIMSTM11   3
#define TIMSTM10   2
#define TIMSTM9    1
#define TIMSTM8    0

        /* CANSTML */
#define TIMSTM7    7
#define TIMSTM6    6
#define TIMSTM5    5
#define TIMSTM4    4
#define TIMSTM3    3
#define TIMSTM2    2
#define TIMSTM1    1
#define TIMSTM0    0

        /* CANIDM1 */
#define IDMSK28    7
#define IDMSK27    6
#define IDMSK26    5
#define IDMSK25    4
#define IDMSK24    3
#define IDMSK23    2
#define IDMSK22    1
#define IDMSK21    0

        /* CANIDM2 */
#define IDMSK20    7
#define IDMSK19    6
#define IDMSK18    5
#define IDMSK17    4
#define IDMSK16    3
#define IDMSK15    2
#define IDMSK14    1
#define IDMSK13    0

        /* CANIDM3 */
#define IDMSK12    7
#define IDMSK11    6
#define IDMSK10    5
#define IDMSK9     4
#define IDMSK8     3
#define IDMSK7     2
#define IDMSK6     1
#define IDMSK5     0

        /* CANIDM4 */
#define IDMSK4     7
#define IDMSK3     6
#define IDMSK2     5
#define IDMSK1     4
#define IDMSK0     3
#define RTRMSK     2

#define IDEMSK     0

        /* CANIDT1 */
#define IDT28      7
#define IDT27      6
#define IDT26      5
#define IDT25      4
#define IDT24      3
#define IDT23      2
#define IDT22      1
#define IDT21      0

        /* CANIDT2 */
#define IDT20      7
#define IDT19      6
#define IDT18      5
#define IDT17      4
#define IDT16      3
#define IDT15      2
#define IDT14      1
#define IDT13      0

        /* CANIDT3 */
#define IDT12      7
#define IDT11      6
#define IDT10      5
#define IDT9       4
#define IDT8       3
#define IDT7       2
#define IDT6       1
#define IDT5       0

        /* CANIDT4 */
#define IDT4       7
#define IDT3       6
#define IDT2       5
#define IDT1       4
#define IDT0       3
#define RTRTAG     2
#define RB1TAG     1
#define RB0TAG     0

        /* CANCDMOB */
#define CONMOB1     7
#define CONMOB0     6
#define RPLV        5
#define IDE         4
#define DLC3        3
#define DLC2        2
#define DLC1        1
#define DLC0        0

        /* CANSTMOB */
#define DLCW        7
#define TXOK        6
#define RXOK        5
#define BERR        4
#define SERR        3
#define CERR        2
#define FERR        1
#define AERR        0

        /* CANPAGE */
#define MOBNB3     7
#define MOBNB2     6
#define MOBNB1     5
#define MOBNB0     4
#define AINC       3
#define INDX2      2
#define INDX1      1
#define INDX0      0

        /* CANHPMOB */
#define HPMOB3      7
#define HPMOB2      6
#define HPMOB1      5
#define HPMOB0      4
#define CGP3        3
#define CGP2        2
#define CGP1        1
#define CGP0        0

        /* CANREC */
#define REC7      7
#define REC6      6
#define REC5      5
#define REC4      4
#define REC3      3
#define REC2      2
#define REC1      1
#define REC0      0

        /* CANTEC */
#define TEC7      7
#define TEC6      6
#define TEC5      5
#define TEC4      4
#define TEC3      3
#define TEC2      2
#define TEC1      1
#define TEC0      0

        /* CANTTCH */
#define TIMTTC15   7
#define TIMTTC14   6
#define TIMTTC13   5
#define TIMTTC12   4
#define TIMTTC11   3
#define TIMTTC10   2
#define TIMTTC9    1
#define TIMTTC8    0

        /* CANTTCL */
#define TIMTTC7    7
#define TIMTTC6    6
#define TIMTTC5    5
#define TIMTTC4    4
#define TIMTTC3    3
#define TIMTTC2    2
#define TIMTTC1    1
#define TIMTTC0    0

        /* CANTIMH */
#define CANTIM15   7
#define CANTIM14   6
#define CANTIM13   5
#define CANTIM12   4
#define CANTIM11   3
#define CANTIM10   2
#define CANTIM9    1
#define CANTIM8    0

        /* CANTIML */
#define CANTIM7    7
#define CANTIM6    6
#define CANTIM5    5
#define CANTIM4    4
#define CANTIM3    3
#define CANTIM2    2
#define CANTIM1    1
#define CANTIM0    0

        /* CANTCON */
#define TPRSC7     7
#define TPRSC6     6
#define TPRSC5     5
#define TPRSC4     4
#define TPRSC3     3
#define TPRSC2     2
#define TRPSC1     1
#define TPRSC0     0

        /* CANBT3 */

#define PHS22     6
#define PHS21     5
#define PHS20     4
#define PHS12     3
#define PHS11     2
#define PHS10     1
#define SMP       0

        /* CANBT2 */

#define SJW1      6
#define SJW0      5

#define PRS2      3
#define PRS1      2
#define PRS0      1


        /* CANBT1 */

#define BRP5      6
#define BRP4      5
#define BRP3      4
#define BRP2      3
#define BRP1      2
#define BRP0      1


        /* CANSIT1 */

#define SIT14      6
#define SIT13      5
#define SIT12      4
#define SIT11      3
#define SIT10      2
#define SIT9       1
#define SIT8       0

        /* CANSIT2 */
#define SIT7       7
#define SIT6       6
#define SIT5       5
#define SIT4       4
#define SIT3       3
#define SIT2       2
#define SIT1       1
#define SIT0       0

        /* CANIE1 */

#define IEMOB14   6
#define IEMOB13   5
#define IEMOB12   4
#define IEMOB11   3
#define IEMOB10   2
#define IEMOB9    1
#define IEMOB8    0

        /* CANIE2 */
#define IEMOB7    7
#define IEMOB6    6
#define IEMOB5    5
#define IEMOB4    4
#define IEMOB3    3
#define IEMOB2    2
#define IEMOB1    1
#define IEMOB0    0

        /* CANEN1 */

#define ENMOB14   6
#define ENMOB13   5
#define ENMOB12   4
#define ENMOB11   3
#define ENMOB10   2
#define ENMOB9    1
#define ENMOB8    0

        /* CANEN2 */
#define ENMOB7    7
#define ENMOB6    6
#define ENMOB5    5
#define ENMOB4    4
#define ENMOB3    3
#define ENMOB2    2
#define ENMOB1    1
#define ENMOB0    0

        /* CANGIE */
#define ENIT      7
#define ENBOFF    6
#define ENRX      5
#define ENTX      4
#define ENERR     3
#define ENBX      2
#define ENERG     1
#define ENOVRT    0

        /* CANGIT */
#define CANIT     7
#define BOFFIT    6
#define OVRTIM    5
#define BXOK      4
#define SERG      3
#define CERG      2
#define FERG      1
#define AERG      0

        /* CANGSTA */

#define OVRG       6

#define TXBSY      4
#define RXBSY      3
#define ENFG       2
#define BOFF       1
#define ERRP       0

        /* CANGCON */
#define ABRQ       7
#define OVRQ       6
#define TTC        5
#define SYNTTC     4
#define LISTEN     3
#define TEST       2
#define ENASTB     1
#define SWRES      0

        /* UDR1 */
#define UDR17   7
#define UDR16   6
#define UDR15   5
#define UDR14   4
#define UDR13   3
#define UDR12   2
#define UDR11   1
#define UDR10   0

        /* UBRR1H */




#define UBRR111   3
#define UBRR110   2
#define UBRR19    1
#define UBRR18    0

        /* UBRR1L */
#define UBRR17    7
#define UBRR16    6
#define UBRR15    5
#define UBRR14    4
#define UBRR13    3
#define UBRR12    2
#define UBRR11    1
#define UBRR10    0

        /* UCSR1C */

#define UMSEL1    6
#define UPM11     5
#define UPM10     4
#define USBS1     3
#define UCSZ11    2
#define UCSZ10    1
#define UCPOL1    0

        /* UCSR1B */
#define RXCIE1    7
#define TXCIE1    6
#define UDRIE1    5
#define RXEN1     4
#define TXEN1     3
#define UCSZ12    2
#define RXB81     1
#define TXB81     0

        /* UCSR1A */
#define RXC1      7
#define TXC1      6
#define UDRE1     5
#define FE1       4
#define DOR1      3
#define UPE1      2
#define U2X1      1
#define MPCM1     0

        /* UDR0 */
#define UDR07   7
#define UDR06   6
#define UDR05   5
#define UDR04   4
#define UDR03   3
#define UDR02   2
#define UDR01   1
#define UDR00   0

        /* UBRR0H */




#define UBRR011   3
#define UBRR010   2
#define UBRR09    1
#define UBRR08    0

        /* UBRR0L */
#define UBRR07    7
#define UBRR06    6
#define UBRR05    5
#define UBRR04    4
#define UBRR03    3
#define UBRR02    2
#define UBRR01    1
#define UBRR00    0

        /* UCSR0C */

#define UMSEL0    6
#define UPM01     5
#define UPM00     4
#define USBS0     3
#define UCSZ01    2
#define UCSZ00    1
#define UCPOL0    0

        /* UCSR0B */
#define RXCIE0    7
#define TXCIE0    6
#define UDRIE0    5
#define RXEN0     4
#define TXEN0     3
#define UCSZ02    2
#define RXB80     1
#define TXB80     0

        /* UCSR0A */
#define RXC0      7
#define TXC0      6
#define UDRE0     5
#define FE0       4
#define DOR0      3
#define UPE0      2
#define U2X0      1
#define MPCM0     0

        /* TWCR */
#define TWINT   7
#define TWEA    6
#define TWSTA   5
#define TWSTO   4
#define TWWC    3
#define TWEN    2

#define TWIE    0

        /* TWDR */
#define TWDR7   7
#define TWDR6   6
#define TWDR5   5
#define TWDR4   4
#define TWDR3   3
#define TWDR2   2
#define TWDR1   1
#define TWDR0   0

        /* TWAR */
#define TWAR6   7
#define TWAR5   6
#define TWAR4   5
#define TWAR3   4
#define TWAR2   3
#define TWAR1   2
#define TWAR0   1
#define TWGCE   0

        /* TWSR */
#define TWS7    7
#define TWS6    6
#define TWS5    5
#define TWS4    4
#define TWS3    3

#define TWPS1   1
#define TWPS0   0

        /* TWBR */
#define TWBR7   7
#define TWBR6   6
#define TWBR5   5
#define TWBR4   4
#define TWBR3   3
#define TWBR2   2
#define TWBR1   1
#define TWBR0   0

        /* ASSR */



#define EXCLK   4
#define AS2     3
#define TCN2UB  2
#define OCR2UB  1
#define TCR2UB  0

        /* OCR2A */
#define OCR2A7   7
#define OCR2A6   6
#define OCR2A5   5
#define OCR2A4   4
#define OCR2A3   3
#define OCR2A2   2
#define OCR2A1   1
#define OCR2A0   0

        /* TCNT2 */
#define TCNT27   7
#define TCNT26   6
#define TCNT25   5
#define TCNT24   4
#define TCNT23   3
#define TCNT22   2
#define TCNT21   1
#define TCNT20   0

        /* TCCR2A */
#define FOC2A     7
#define WGM20     6
#define COM2A1    5
#define COM2A0    4
#define WGM21     3
#define CS22      2
#define CS21      1
#define CS20      0

        /* OCR3CH */
#define OCR3C15   7
#define OCR3C14   6
#define OCR3C13   5
#define OCR3C12   4
#define OCR3C11   3
#define OCR3C10   2
#define OCR3C9    1
#define OCR3C8    0

        /* OCR3CL */
#define OCR3C7    7
#define OCR3C6    6
#define OCR3C5    5
#define OCR3C4    4
#define OCR3C3    3
#define OCR3C2    2
#define OCR3C1    1
#define OCR3C0    0

        /* OCR3BH */
#define OCR3B15   7
#define OCR3B14   6
#define OCR3B13   5
#define OCR3B12   4
#define OCR3B11   3
#define OCR3B10   2
#define OCR3B9    1
#define OCR3B8    0

        /* OCR3BL */
#define OCR3B7    7
#define OCR3B6    6
#define OCR3B5    5
#define OCR3B4    4
#define OCR3B3    3
#define OCR3B2    2
#define OCR3B1    1
#define OCR3B0    0

        /* OCR3AH */
#define OCR3A15   7
#define OCR3A14   6
#define OCR3A13   5
#define OCR3A12   4
#define OCR3A11   3
#define OCR3A10   2
#define OCR3A9    1
#define OCR3A8    0

        /* OCR3AL */
#define OCR3A7    7
#define OCR3A6    6
#define OCR3A5    5
#define OCR3A4    4
#define OCR3A3    3
#define OCR3A2    2
#define OCR3A1    1
#define OCR3A0    0

        /* ICR3H */
#define ICR315   7
#define ICR314   6
#define ICR313   5
#define ICR312   4
#define ICR311   3
#define ICR310   2
#define ICR39    1
#define ICR38    0

        /* ICR3L */
#define ICR37    7
#define ICR36    6
#define ICR35    5
#define ICR34    4
#define ICR33    3
#define ICR32    2
#define ICR31    1
#define ICR30    0

        /* TCNT3H */
#define TCNT315   7
#define TCNT314   6
#define TCNT313   5
#define TCNT312   4
#define TCNT311   3
#define TCNT310   2
#define TCNT39    1
#define TCNT38    0

        /* TCNT3L */
#define TCNT37    7
#define TCNT36    6
#define TCNT35    5
#define TCNT34    4
#define TCNT33    3
#define TCNT32    2
#define TCNT31    1
#define TCNT30    0

        /* TCCR3C */
#define FOC3A     7
#define FOC3B     6
#define FOC3C     5






        /* TCCR3B */
#define ICNC3     7
#define ICES3     6

#define WGM33     4
#define WGM32     3
#define CS32      2
#define CS31      1
#define CS30      0

        /* TCCR3A */
#define COM3A1    7
#define COM3A0    6
#define COM3B1    5
#define COM3B0    4
#define COM3C1    3
#define COM3C0    2
#define WGM31     1
#define WGM30     0

        /* OCR1CH */
#define OCR1C15   7
#define OCR1C14   6
#define OCR1C13   5
#define OCR1C12   4
#define OCR1C11   3
#define OCR1C10   2
#define OCR1C9    1
#define OCR1C8    0

        /* OCR1CL */
#define OCR1C7    7
#define OCR1C6    6
#define OCR1C5    5
#define OCR1C4    4
#define OCR1C3    3
#define OCR1C2    2
#define OCR1C1    1
#define OCR1C0    0

        /* OCR1BH */
#define OCR1B15   7
#define OCR1B14   6
#define OCR1B13   5
#define OCR1B12   4
#define OCR1B11   3
#define OCR1B10   2
#define OCR1B9    1
#define OCR1B8    0

        /* OCR1BL */
#define OCR1B7    7
#define OCR1B6    6
#define OCR1B5    5
#define OCR1B4    4
#define OCR1B3    3
#define OCR1B2    2
#define OCR1B1    1
#define OCR1B0    0

        /* OCR1AH */
#define OCR1A15   7
#define OCR1A14   6
#define OCR1A13   5
#define OCR1A12   4
#define OCR1A11   3
#define OCR1A10   2
#define OCR1A9    1
#define OCR1A8    0

        /* OCR1AL */
#define OCR1A7    7
#define OCR1A6    6
#define OCR1A5    5
#define OCR1A4    4
#define OCR1A3    3
#define OCR1A2    2
#define OCR1A1    1
#define OCR1A0    0

        /* ICR1H */
#define ICR115   7
#define ICR114   6
#define ICR113   5
#define ICR112   4
#define ICR111   3
#define ICR110   2
#define ICR19    1
#define ICR18    0

        /* ICR1L */
#define ICR17    7
#define ICR16    6
#define ICR15    5
#define ICR14    4
#define ICR13    3
#define ICR12    2
#define ICR11    1
#define ICR10    0

        /* TCNT1H */
#define TCNT115   7
#define TCNT114   6
#define TCNT113   5
#define TCNT112   4
#define TCNT111   3
#define TCNT110   2
#define TCNT19    1
#define TCNT18    0

        /* TCNT1L */
#define TCNT17    7
#define TCNT16    6
#define TCNT15    5
#define TCNT14    4
#define TCNT13    3
#define TCNT12    2
#define TCNT11    1
#define TCNT10    0

        /* TCCR1C */
#define FOC1A     7
#define FOC1B     6
#define FOC1C     5






        /* TCCR1B */
#define ICNC1     7
#define ICES1     6

#define WGM13     4
#define WGM12     3
#define CS12      2
#define CS11      1
#define CS10      0

        /* TCCR1A */
#define COM1A1    7
#define COM1A0    6
#define COM1B1    5
#define COM1B0    4
#define COM1C1    3
#define COM1C0    2
#define WGM11     1
#define WGM10     0

        /* DIDR1 */






#define AIN1D    1
#define AIN0D    0

        /* DIDR0 */
#define ADC7D    7
#define ADC6D    6
#define ADC5D    5
#define ADC4D    4
#define ADC3D    3
#define ADC2D    2
#define ADC1D    1
#define ADC0D    0

        /* ADMUX */
#define REFS1    7
#define REFS0    6
#define ADLAR    5
#define MUX4     4
#define MUX3     3
#define MUX2     2
#define MUX1     1
#define MUX0     0

        /* ADCSRB */
#define ADHSM     7
#define ACME      6



#define ADTS2     2
#define ADTS1     1
#define ADTS0     0

        /* ADCSRA */
#define ADEN      7
#define ADSC      6
#define ADATE     5
#define ADIF      4
#define ADIE      3
#define ADPS2     2
#define ADPS1     1
#define ADPS0     0

        /* XMCRB */
#define XMBK     7




#define XMM2     2
#define XMM1     1
#define XMM0     0

        /* XMCRA */
#define SRE      7
#define SRL2     6
#define SRL1     5
#define SRL0     4
#define SRW11    3
#define SRW10    2
#define SRW01    1
#define SRW00    0

        /* TIMSK3 */


#define ICIE3     5

#define OCIE3C    3
#define OCIE3B    2
#define OCIE3A    1
#define TOIE3     0

        /* TIMSK2 */






#define OCIE2A    1
#define TOIE2     0

        /* TIMSK1 */


#define ICIE1     5

#define OCIE1C    3
#define OCIE1B    2
#define OCIE1A    1
#define TOIE1     0

        /* TIMSK0 */






#define OCIE0A    1
#define TOIE0     0

        /* EICRB */
#define ISC71    7
#define ISC70    6
#define ISC61    5
#define ISC60    4
#define ISC51    3
#define ISC50    2
#define ISC41    1
#define ISC40    0

        /* EICRA */
#define ISC31    7
#define ISC30    6
#define ISC21    5
#define ISC20    4
#define ISC11    3
#define ISC10    2
#define ISC01    1
#define ISC00    0

        /* OSCCAL */

#define CAL6      6
#define CAL5      5
#define CAL4      4
#define CAL3      3
#define CAL2      2
#define CAL1      1
#define CAL0      0

        /* CLKPR */
#define CLKPCE   7



#define CLKPS3   3
#define CLKPS2   2
#define CLKPS1   1
#define CLKPS0   0

        /* WDTCR */



#define WDCE     4
#define WDE      3
#define WDP2     2
#define WDP1     1
#define WDP0     0

        /* SPH */
#define SP15   7
#define SP14   6
#define SP13   5
#define SP12   4
#define SP11   3
#define SP10   2
#define SP9    1
#define SP8    0

        /* SPL */
#define SP7    7
#define SP6    6
#define SP5    5
#define SP4    4
#define SP3    3
#define SP2    2
#define SP1    1
#define SP0    0

        /* RAMPZ */







#define RAMPZ0   0

        /* SPMCSR */
#define SPMIE     7
#define RWWSB     6

#define RWWSRE    4
#define BLBSET    3
#define PGWRT     2
#define PGERS     1
#define SPMEN     0

        /* MCUCR */
#define JTD      7


#define PUD      4


#define IVSEL    1
#define IVCE     0

        /* MCUSR */



#define JTRF     4
#define WDRF     3
#define BORF     2
#define EXTRF    1
#define PORF     0

        /* SMCR */




#define SM2     3
#define SM1     2
#define SM0     1
#define SE      0

        /* OCDR */
#define IDRD    7
#define OCDR7   7
#define OCDR6   6
#define OCDR5   5
#define OCDR4   4
#define OCDR3   3
#define OCDR2   2
#define OCDR1   1
#define OCDR0   0

        /* ACSR */
#define ACD     7
#define ACBG    6
#define ACO     5
#define ACI     4
#define ACIE    3
#define ACIC    2
#define ACIS1   1
#define ACIS0   0

        /* SPDR */
#define SPD7    7
#define SPD6    6
#define SPD5    5
#define SPD4    4
#define SPD3    3
#define SPD2    2
#define SPD1    1
#define SPD0    0

        /* SPSR */
#define SPIF    7
#define WCOL    6





#define SPI2X   0

        /* SPCR */
#define SPIE    7
#define SPE     6
#define DORD    5
#define MSTR    4
#define CPOL    3
#define CPHA    2
#define SPR1    1
#define SPR0    0

        /* GPIOR2 */
#define GPIOR27   7
#define GPIOR26   6
#define GPIOR25   5
#define GPIOR24   4
#define GPIOR23   3
#define GPIOR22   2
#define GPIOR21   1
#define GPIOR20   0

        /* GPIOR1 */
#define GPIOR17   7
#define GPIOR16   6
#define GPIOR15   5
#define GPIOR14   4
#define GPIOR13   3
#define GPIOR12   2
#define GPIOR11   1
#define GPIOR10   0

        /* OCR0A */
#define OCR0A7   7
#define OCR0A6   6
#define OCR0A5   5
#define OCR0A4   4
#define OCR0A3   3
#define OCR0A2   2
#define OCR0A1   1
#define OCR0A0   0

        /* TCNT0 */
#define TCNT07   7
#define TCNT06   6
#define TCNT05   5
#define TCNT04   4
#define TCNT03   3
#define TCNT02   2
#define TCNT01   1
#define TCNT00   0

        /* TCCR0A */
#define FOC0A     7
#define WGM00     6
#define COM0A1    5
#define COM0A0    4
#define WGM01     3
#define CS02      2
#define CS01      1
#define CS00      0

        /* GTCCR */
#define TSM      7





#define PSR2     1
#define PSR310   0

        /* EEARH */




#define EEAR11   3
#define EEAR10   2
#define EEAR9    1
#define EEAR8    0

        /* EEARL */
#define EEAR7    7
#define EEAR6    6
#define EEAR5    5
#define EEAR4    4
#define EEAR3    3
#define EEAR2    2
#define EEAR1    1
#define EEAR0    0

        /* EEDR */
#define EEDR7   7
#define EEDR6   6
#define EEDR5   5
#define EEDR4   4
#define EEDR3   3
#define EEDR2   2
#define EEDR1   1
#define EEDR0   0

        /* EECR */




#define EERIE   3
#define EEMWE   2
#define EEWE    1
#define EERE    0

        /* GPIOR0 */
#define GPIOR07   7
#define GPIOR06   6
#define GPIOR05   5
#define GPIOR04   4
#define GPIOR03   3
#define GPIOR02   2
#define GPIOR01   1
#define GPIOR00   0

        /* EIMSK */
#define INT7     7
#define INT6     6
#define INT5     5
#define INT4     4
#define INT3     3
#define INT2     2
#define INT1     1
#define INT0     0

        /* EIFR */
#define INTF7   7
#define INTF6   6
#define INTF5   5
#define INTF4   4
#define INTF3   3
#define INTF2   2
#define INTF1   1
#define INTF0   0

        /* TIFR3 */


#define ICF3     5

#define OCF3C    3
#define OCF3B    2
#define OCF3A    1
#define TOV3     0

        /* TIFR2 */






#define OCF2A    1
#define TOV2     0

        /* TIFR1 */


#define ICF1     5

#define OCF1C    3
#define OCF1B    2
#define OCF1A    1
#define TOV1     0

        /* TIFR0 */






#define OCF0A    1
#define TOV0     0

        /* PORTG */



#define PORTG4   4
#define PORTG3   3
#define PORTG2   2
#define PORTG1   1
#define PORTG0   0

        /* PORTG */



#define PG4   4
#define PG3   3
#define PG2   2
#define PG1   1
#define PG0   0

        /* DDRG */



#define DDG4    4
#define DDG3    3
#define DDG2    2
#define DDG1    1
#define DDG0    0

        /* PING */



#define PING4   4
#define PING3   3
#define PING2   2
#define PING1   1
#define PING0   0

        /* PORTF */
#define PORTF7   7
#define PORTF6   6
#define PORTF5   5
#define PORTF4   4
#define PORTF3   3
#define PORTF2   2
#define PORTF1   1
#define PORTF0   0

        /* PORTF */
#define PF7   7
#define PF6   6
#define PF5   5
#define PF4   4
#define PF3   3
#define PF2   2
#define PF1   1
#define PF0   0

        /* DDRF */
#define DDF7    7
#define DDF6    6
#define DDF5    5
#define DDF4    4
#define DDF3    3
#define DDF2    2
#define DDF1    1
#define DDF0    0

        /* PINF */
#define PINF7   7
#define PINF6   6
#define PINF5   5
#define PINF4   4
#define PINF3   3
#define PINF2   2
#define PINF1   1
#define PINF0   0

        /* PORTE */
#define PORTE7   7
#define PORTE6   6
#define PORTE5   5
#define PORTE4   4
#define PORTE3   3
#define PORTE2   2
#define PORTE1   1
#define PORTE0   0

        /* PORTE */
#define PE7   7
#define PE6   6
#define PE5   5
#define PE4   4
#define PE3   3
#define PE2   2
#define PE1   1
#define PE0   0

        /* DDRE */
#define DDE7    7
#define DDE6    6
#define DDE5    5
#define DDE4    4
#define DDE3    3
#define DDE2    2
#define DDE1    1
#define DDE0    0

        /* PINE */
#define PINE7   7
#define PINE6   6
#define PINE5   5
#define PINE4   4
#define PINE3   3
#define PINE2   2
#define PINE1   1
#define PINE0   0

        /* PORTD */
#define PORTD7   7
#define PORTD6   6
#define PORTD5   5
#define PORTD4   4
#define PORTD3   3
#define PORTD2   2
#define PORTD1   1
#define PORTD0   0

        /* PORTD */
#define PD7   7
#define PD6   6
#define PD5   5
#define PD4   4
#define PD3   3
#define PD2   2
#define PD1   1
#define PD0   0

        /* DDRD */
#define DDD7    7
#define DDD6    6
#define DDD5    5
#define DDD4    4
#define DDD3    3
#define DDD2    2
#define DDD1    1
#define DDD0    0

        /* PIND */
#define PIND7   7
#define PIND6   6
#define PIND5   5
#define PIND4   4
#define PIND3   3
#define PIND2   2
#define PIND1   1
#define PIND0   0

        /* PORTC */
#define PORTC7   7
#define PORTC6   6
#define PORTC5   5
#define PORTC4   4
#define PORTC3   3
#define PORTC2   2
#define PORTC1   1
#define PORTC0   0

        /* PORTC */
#define PC7   7
#define PC6   6
#define PC5   5
#define PC4   4
#define PC3   3
#define PC2   2
#define PC1   1
#define PC0   0

        /* DDRC */
#define DDC7    7
#define DDC6    6
#define DDC5    5
#define DDC4    4
#define DDC3    3
#define DDC2    2
#define DDC1    1
#define DDC0    0

        /* PINC */
#define PINC7   7
#define PINC6   6
#define PINC5   5
#define PINC4   4
#define PINC3   3
#define PINC2   2
#define PINC1   1
#define PINC0   0

        /* PORTB */
#define PORTB7   7
#define PORTB6   6
#define PORTB5   5
#define PORTB4   4
#define PORTB3   3
#define PORTB2   2
#define PORTB1   1
#define PORTB0   0

        /* PORTB */
#define PB7   7
#define PB6   6
#define PB5   5
#define PB4   4
#define PB3   3
#define PB2   2
#define PB1   1
#define PB0   0

        /* DDRB */
#define DDB7    7
#define DDB6    6
#define DDB5    5
#define DDB4    4
#define DDB3    3
#define DDB2    2
#define DDB1    1
#define DDB0    0

        /* PINB */
#define PINB7   7
#define PINB6   6
#define PINB5   5
#define PINB4   4
#define PINB3   3
#define PINB2   2
#define PINB1   1
#define PINB0   0

        /* PORTA */
#define PORTA7   7
#define PORTA6   6
#define PORTA5   5
#define PORTA4   4
#define PORTA3   3
#define PORTA2   2
#define PORTA1   1
#define PORTA0   0

        /* PORTA */
#define PA7   7
#define PA6   6
#define PA5   5
#define PA4   4
#define PA3   3
#define PA2   2
#define PA1   1
#define PA0   0

        /* DDRA */
#define DDA7    7
#define DDA6    6
#define DDA5    5
#define DDA4    4
#define DDA3    3
#define DDA2    2
#define DDA1    1
#define DDA0    0

        /* PINA */
#define PINA7   7
#define PINA6   6
#define PINA5   5
#define PINA4   4
#define PINA3   3
#define PINA2   2
#define PINA1   1
#define PINA0   0


/* Pointer definition */
#define    XL     r26
#define    XH     r27
#define    YL     r28
#define    YH     r29
#define    ZL     r30
#define    ZH     r31

/* Contants */
#define    RAMEND   0x10FF    /*Last On-Chip SRAM location*/
#define    XRAMEND  0xFFFF
#define    E2END    0x0FFF
#define    FLASHEND 0x1FFFF

#endif /* ENABLE_BIT_DEFINITIONS */ 
#endif /* __IOCAN128_H (define part) */
#endif /* __IOCAN128_H (SFR part) */
